@@ -22,18 +22,6 @@ impl MethodDef {
         self.0.str(3)
     }
 
-    pub fn parent(&self) -> TypeDef {
-        let row = self.0.file.upper_bound_of(
-            TableIndex::TypeDef,
-            0,
-            self.0.file.tables[TableIndex::TypeDef as usize].row_count,
-            5,
-            self.0.row + 1,
-        ) - 1;
-
-        Row::new(row, TableIndex::TypeDef, self.0.file).into()
-    }
-
     pub fn rust_name(&self) -> String {
         let name = self.name();
 
@@ -79,6 +67,23 @@ impl MethodDef {
         self.has_attribute("DeprecatedAttribute")
     }
 
+    pub fn supported_arch(&self) -> Option<&'static str> {
+        self.attributes()
+            .filter_map(|attribute| match attribute.name() {
+                "SupportedArchitectureAttribute" => {
+                    let args = attribute.args();
+                    match &args[0].1 {
+                        ConstantValue::I32(1) => Some("x86"),
+                        ConstantValue::I32(2) => Some("x86_64"),
+                        ConstantValue::I32(4) => Some("aarch64"),
+                        _ => None,
+                    }
+                }
+                _ => None,
+            })
+            .next()
+    }
+
     pub fn static_lib(&self) -> Option<String> {
         self.attributes()
             .filter_map(|attribute| match attribute.name() {
@@ -114,7 +119,7 @@ impl MethodDef {
         blob.read_unsigned();
         blob.read_unsigned(); // parameter count
 
-        let return_sig = reader.signature_from_blob(&mut blob, generics);
+        let return_sig = reader.signature_from_blob(&mut blob, None, generics);
         let mut return_param = None;
 
         let params = params
@@ -126,7 +131,7 @@ impl MethodDef {
                     Some(MethodParam {
                         param,
                         signature: reader
-                            .signature_from_blob(&mut blob, generics)
+                            .signature_from_blob(&mut blob, None, generics)
                             .expect("MethodDef"),
                     })
                 }
@@ -140,7 +145,8 @@ impl MethodDef {
         }
     }
 
-    pub fn dependencies(&self) -> Vec<TypeEntry> {
-        self.signature(&[]).dependencies(TypeInclude::Minimal)
+    pub fn include_dependencies(&self) {
+        self.signature(&[])
+            .include_dependencies(TypeInclude::Minimal)
     }
 }
