@@ -28,6 +28,10 @@ impl Param {
         self.flags().input()
     }
 
+    pub fn is_optional(&self) -> bool {
+        self.flags().optional()
+    }
+
     pub fn is_com_out_ptr(&self) -> bool {
         self.has_attribute("ComOutPtrAttribute")
     }
